@@ -25,7 +25,7 @@ refresh_time = {}
 def refresh_session(session):
     id = session.session_id.get('id')
     last_refresh_time = refresh_time.get(id)
-    if last_refresh_time is None or time.time() - last_refresh_time < 240:
+    if last_refresh_time is not None and time.time() - last_refresh_time < 180:
         print(f'last refresh time too short, ignore refresh request ')
         return
     mongo_db.command("refreshSessions", [{'id': id}])
